@@ -28,13 +28,13 @@ summary.fsQCApt <- function(object, ...){
     print(object$call)
     cat("\n")
     cat("Counterexamples\n")
-	printCoefmat(object$result.cex[,1:5], P.values=TRUE, has.Pvalue=TRUE, tst.ind=1, signif.legend=FALSE)
+	printCoefmat(object$result.cex[,c(1,3,2,5,7)])
     cat("\n")
     cat("Consistency\n")
-	printCoefmat(object$result.con[,1:5], P.values=TRUE, has.Pvalue=TRUE)
+	printCoefmat(object$result.con[,c(1,2,3,5,7)])
 	cat("\n")
     cat(paste("Total number of configurations:", object$total.configurations), "\n")
-    cat(paste("Number of permutations:", length(object$permutations.cex)), "\n")
+    cat(paste("Number of permutations:", length(object$permutations.cex[[1]])), "\n")
     cat(paste("p-value adjustment method:", object$p.adj.method))
     cat("\n")
     cat("\n")
